@@ -52,14 +52,12 @@
 #include <panel/panel-dialogs.h>
 #include <panel/panel-plugin-external.h>
 
-#define AUTOSAVE_INTERVAL   (10 * 60)
-#define MIGRATE_BIN         HELPERDIR G_DIR_SEPARATOR_S "migrate"
+#define MIGRATE_BIN HELPERDIR G_DIR_SEPARATOR_S "migrate"
 
 
 
 static void      panel_application_dispose            (GObject                *object);
 static void      panel_application_finalize           (GObject                *object);
-static gboolean  panel_application_autosave_timer     (gpointer                user_data);
 static void      panel_application_plugin_move        (GtkWidget              *item,
                                                        PanelApplication       *application);
 static gboolean  panel_application_plugin_insert      (PanelApplication       *application,
@@ -124,9 +122,6 @@ struct _PanelApplication
   /* internal list of opened dialogs */
   GSList             *dialogs;
 
-  /* autosave timer for plugins */
-  guint               autosave_timer_id;
-
   /* autohide count at application level */
   gint                autohide_block;
 
@@ -228,10 +223,6 @@ panel_application_init (PanelApplication *application)
 
   /* get a factory reference so it never unloads */
   application->factory = panel_module_factory_get ();
-
-  /* start the autosave timer for plugins */
-  application->autosave_timer_id = g_timeout_add_seconds (60 * 10,
-      panel_application_autosave_timer, application);
 }
 
 
@@ -243,12 +234,7 @@ panel_application_dispose (GObject *object)
 
   /* save plugins: xfconf_shutdown() is called via a weak ref i.e. on dispose(),
    * so this should be done here to avoid any use-after-free */
-  if (application->autosave_timer_id != 0)
-    {
-      g_source_remove (application->autosave_timer_id);
-      application->autosave_timer_id = 0;
-      panel_application_autosave_timer (application);
-    }
+  panel_application_save (application, SAVE_PLUGIN_PROVIDERS);
 
   (*G_OBJECT_CLASS (panel_application_parent_class)->dispose) (object);
 }
@@ -282,19 +268,6 @@ panel_application_finalize (GObject *object)
 
 
 
-static gboolean
-panel_application_autosave_timer (gpointer user_data)
-{
-  PanelApplication *application = PANEL_APPLICATION (user_data);
-
-  /* emit a save signal for the plugins */
-  panel_application_save (application, SAVE_PLUGIN_PROVIDERS);
-
-  return TRUE;
-}
-
-
-
 static void
 panel_application_xfconf_window_bindings (PanelApplication *application,
                                           PanelWindow      *window,
