@@ -185,6 +185,15 @@ panel_base_window_class_init (PanelBaseWindowClass *klass)
 
 
 
+static void
+panel_base_window_scale_factor_changed (PanelBaseWindow *window)
+{
+  if (window->background_style == PANEL_BG_STYLE_IMAGE && window->background_image != NULL)
+    panel_base_window_set_background_image_css (window);
+}
+
+
+
 static void
 panel_base_window_init (PanelBaseWindow *window)
 {
@@ -220,6 +229,7 @@ panel_base_window_init (PanelBaseWindow *window)
   context = gtk_widget_get_style_context (GTK_WIDGET (window));
   gtk_style_context_add_class (context, "panel");
   gtk_style_context_add_class (context, "xfce4-panel");
+  g_signal_connect (window, "notify::scale-factor", G_CALLBACK (panel_base_window_scale_factor_changed), NULL);
 }
 
 
@@ -598,17 +608,29 @@ panel_base_window_set_background_color_css (PanelBaseWindow *window)
 static void
 panel_base_window_set_background_image_css (PanelBaseWindow *window)
 {
-  gchar *css_string;
+  gchar *css_url, *css_string;
+  gint scale_factor;
 
   panel_return_if_fail (window->background_image != NULL);
 
-  css_string = g_strdup_printf (".xfce4-panel.background { background: url(\"%s\");"
+  /* do not scale background image with the panel */
+  scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (window));
+  css_url = g_strdup_printf ("url(\"%s\")", window->background_image);
+  for (gint i = 1; i < scale_factor; i++)
+    {
+      gchar *temp = g_strdup_printf ("%s,url(\"%s\")", css_url, window->background_image);
+      g_free (css_url);
+      css_url = temp;
+    }
+
+  css_string = g_strdup_printf (".xfce4-panel.background { background: -gtk-scaled(%s);"
                                                           "border-color: transparent; } %s",
-                                window->background_image, PANEL_BASE_CSS);
+                                css_url, PANEL_BASE_CSS);
 
   panel_base_window_set_background_css (window, css_string);
 
   g_free (css_string);
+  g_free (css_url);
 }
 
 
