@@ -22,7 +22,10 @@
 #include <glib.h>
 #include <gdk/gdk.h>
 
+G_BEGIN_DECLS
+
 gboolean  panel_dbus_client_display_preferences_dialog (guint         active,
+                                                        guint         socket_id,
                                                         GError      **error);
 
 gboolean  panel_dbus_client_display_items_dialog       (guint         active,
