@@ -32,7 +32,6 @@
 #include <panel/panel-module.h>
 #include <panel/panel-module-factory.h>
 #include <panel/panel-plugin-external-wrapper.h>
-#include <panel/panel-plugin-external-46.h>
 
 #define PANEL_PLUGINS_LIB_DIR (LIBDIR G_DIR_SEPARATOR_S "panel" G_DIR_SEPARATOR_S "plugins")
 #define PANEL_PLUGINS_LIB_DIR_OLD (LIBDIR G_DIR_SEPARATOR_S "panel-plugins")
@@ -44,7 +43,6 @@ typedef enum _PanelModuleUnique  PanelModuleUnique;
 
 
 static void      panel_module_dispose          (GObject          *object);
-static void      panel_module_finalize         (GObject          *object);
 static gboolean  panel_module_load             (GTypeModule      *type_module);
 static void      panel_module_unload           (GTypeModule      *type_module);
 static void      panel_module_plugin_destroyed (gpointer          user_data,
@@ -61,8 +59,7 @@ enum _PanelModuleRunMode
 {
   UNKNOWN,    /* Unset */
   INTERNAL,   /* plugin library will be loaded in the panel */
-  WRAPPER,    /* external library with comunication through PanelPluginExternal */
-  EXTERNAL_46 /* external executable with comunication through PanelPluginExternal46 */
+  WRAPPER     /* external library with communication through PanelPluginExternal */
 };
 
 enum _PanelModuleUnique
@@ -79,8 +76,7 @@ struct _PanelModule
   /* module type */
   PanelModuleRunMode   mode;
 
-  /* filename to the library or executable
-   * for an old 4.6 plugin */
+  /* filename of the library */
   gchar               *filename;
 
   /* plugin information from the desktop file */
@@ -92,7 +88,7 @@ struct _PanelModule
   guint                use_count;
   PanelModuleUnique    unique_mode;
 
-  /* module location (null for 4.6 plugins) */
+  /* module location */
   GModule             *library;
 
   /* for non-gobject plugin */
@@ -123,7 +119,6 @@ panel_module_class_init (PanelModuleClass *klass)
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->dispose = panel_module_dispose;
-  gobject_class->finalize = panel_module_finalize;
 
   gtype_module_class = G_TYPE_MODULE_CLASS (klass);
   gtype_module_class->load = panel_module_load;
@@ -154,29 +149,26 @@ panel_module_init (PanelModule *module)
 
 static void
 panel_module_dispose (GObject *object)
-{
-  /* Do nothing to avoid problems with dispose in GTypeModule when
-   * types are registered.
-   *
-   * For us this is not a problem since the modules are released when
-   * everything is destroyed. So we really want that last unref before
-   * closing the application. */
-}
-
-
-
-static void
-panel_module_finalize (GObject *object)
 {
   PanelModule *module = PANEL_MODULE (object);
 
-  g_free (module->filename);
-  g_free (module->display_name);
-  g_free (module->comment);
-  g_free (module->icon_name);
-  g_free (module->api);
+  if (module->api != NULL)
+    {
+      g_free (module->filename);
+      g_free (module->display_name);
+      g_free (module->comment);
+      g_free (module->icon_name);
+      g_free (module->api);
+      module->api = NULL;
+      if (module->plugin_type != G_TYPE_NONE)
+        {
+          /* a module containing type implementations must exist forever */
+          g_object_ref (module);
+          return;
+        }
+    }
 
-  (*G_OBJECT_CLASS (panel_module_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (panel_module_parent_class)->dispose (object);
 }
 
 
@@ -306,7 +298,6 @@ panel_module_new_from_desktop_file (const gchar *filename,
   XfceRc      *rc;
   const gchar *module_name;
   gchar       *path;
-  const gchar *module_exec;
   const gchar *module_unique;
   gboolean     found;
 
@@ -329,6 +320,14 @@ panel_module_new_from_desktop_file (const gchar *filename,
       return NULL;
     }
 
+  if (g_strcmp0 (xfce_rc_read_entry (rc, "X-XFCE-API", "1.0"), "2.0") != 0)
+    {
+      g_critical ("Plugin %s: The Desktop file %s requested the Gtk2 API (v1.0), which is "
+                  "no longer supported.", name, filename);
+      xfce_rc_close (rc);
+      return NULL;
+    }
+
   xfce_rc_set_group (rc, "Xfce Panel");
 
   /* read module location from the desktop file */
@@ -369,8 +368,7 @@ panel_module_new_from_desktop_file (const gchar *filename,
             {
               module->mode = WRAPPER;
               g_free (module->api);
-              //module->api = g_strdup (xfce_rc_read_entry (rc, "X-XFCE-API", LIBXFCE4PANEL_VERSION_API));
-              module->api = g_strdup (xfce_rc_read_entry (rc, "X-XFCE-API", "1.0"));
+              module->api = g_strdup (xfce_rc_read_entry (rc, "X-XFCE-API", LIBXFCE4PANEL_VERSION_API));
             }
           else
             module->mode = INTERNAL;
@@ -382,24 +380,6 @@ panel_module_new_from_desktop_file (const gchar *filename,
           g_free (path);
         }
     }
-  else
-    {
-      /* yeah, we support ancient shizzle too... */
-      module_exec = xfce_rc_read_entry_untranslated (rc, "X-XFCE-Exec", NULL);
-      if (module_exec != NULL
-          && g_path_is_absolute (module_exec)
-          && g_file_test (module_exec, G_FILE_TEST_EXISTS))
-        {
-          module = g_object_new (PANEL_TYPE_MODULE, NULL);
-          module->filename = g_strdup (module_exec);
-          module->mode = EXTERNAL_46;
-        }
-      else
-        {
-          g_critical ("Plugin %s: There was no executable found at \"%s\"",
-                      name, module_exec);
-        }
-    }
 
   if (G_LIKELY (module != NULL))
     {
@@ -499,11 +479,6 @@ panel_module_new_plugin (PanelModule  *module,
       debug_type = "external-wrapper";
       break;
 
-    case EXTERNAL_46:
-      plugin = panel_plugin_external_46_new (module, unique_id, arguments);
-      debug_type = "external-46";
-      break;
-
     default:
       panel_assert_not_reached ();
       break;
