@@ -11,9 +11,9 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __CLOCK_ANALOG_H__
@@ -35,7 +35,8 @@ GType      xfce_clock_analog_get_type      (void) G_GNUC_CONST;
 
 void       xfce_clock_analog_register_type (XfcePanelTypeModule *type_module);
 
-GtkWidget *xfce_clock_analog_new           (void) G_GNUC_MALLOC;
+GtkWidget *xfce_clock_analog_new           (ClockTime           *time,
+                                            ClockSleepMonitor   *sleep_monitor) G_GNUC_MALLOC;
 
 G_END_DECLS
 
